@@ -568,25 +568,6 @@ msgs::Light ignition::gazebo::convert(const sdf::Light &_in)
   out.set_spot_inner_angle(_in.SpotInnerAngle().Radian());
   out.set_spot_outer_angle(_in.SpotOuterAngle().Radian());
   out.set_spot_falloff(_in.SpotFalloff());
-
-  {
-    // todo(ahcorde) Use the field is_light_off in light.proto from
-    // Garden on.
-    auto header = out.mutable_header()->add_data();
-    header->set_key("isLightOn");
-    std::string *value = header->add_value();
-    *value = std::to_string(_in.LightOn());
-  }
-
-  {
-    // todo(ahcorde) Use the field visualize_visual in light.proto from
-    // Garden on.
-    auto header = out.mutable_header()->add_data();
-    header->set_key("visualizeVisual");
-    std::string *value = header->add_value();
-    *value = std::to_string(_in.Visualize());
-  }
-
   if (_in.Type() == sdf::LightType::POINT)
     out.set_type(msgs::Light_LightType_POINT);
   else if (_in.Type() == sdf::LightType::SPOT)
@@ -616,43 +597,6 @@ sdf::Light ignition::gazebo::convert(const msgs::Light &_in)
   out.SetSpotInnerAngle(math::Angle(_in.spot_inner_angle()));
   out.SetSpotOuterAngle(math::Angle(_in.spot_outer_angle()));
   out.SetSpotFalloff(_in.spot_falloff());
-
-  // todo(ahcorde) Use the field is_light_off in light.proto from
-  // Garden on.
-  bool visualizeVisual = true;
-  for (int i = 0; i < _in.header().data_size(); ++i)
-  {
-    for (int j = 0;
-        j < _in.header().data(i).value_size(); ++j)
-    {
-      if (_in.header().data(i).key() ==
-          "visualizeVisual")
-      {
-        visualizeVisual = ignition::math::parseInt(
-          _in.header().data(i).value(0));
-      }
-    }
-  }
-  out.SetVisualize(visualizeVisual);
-
-  // todo(ahcorde) Use the field is_light_off in light.proto from
-  // Garden on.
-  bool isLightOn = true;
-  for (int i = 0; i < _in.header().data_size(); ++i)
-  {
-    for (int j = 0;
-        j < _in.header().data(i).value_size(); ++j)
-    {
-      if (_in.header().data(i).key() ==
-          "isLightOn")
-      {
-        isLightOn = ignition::math::parseInt(
-          _in.header().data(i).value(0));
-      }
-    }
-  }
-  out.SetLightOn(isLightOn);
-
   if (_in.type() == msgs::Light_LightType_POINT)
     out.SetType(sdf::LightType::POINT);
   else if (_in.type() == msgs::Light_LightType_SPOT)
@@ -1616,13 +1560,7 @@ msgs::ParticleEmitter ignition::gazebo::convert(const sdf::ParticleEmitter &_in)
     header->add_value(_in.Topic());
   }
 
-  // todo(anyone) Use particle_scatter_ratio in particle_emitter.proto from
-  // Fortress on.
-  auto header = out.mutable_header()->add_data();
-  header->set_key("particle_scatter_ratio");
-  std::string *value = header->add_value();
-  *value = std::to_string(_in.ScatterRatio());
-
+  out.mutable_particle_scatter_ratio()->set_data(_in.ScatterRatio());
   return out;
 }
 
@@ -1674,6 +1612,8 @@ sdf::ParticleEmitter ignition::gazebo::convert(const msgs::ParticleEmitter &_in)
     out.SetScaleRate(_in.scale_rate().data());
   if (_in.has_color_range_image())
     out.SetColorRangeImage(_in.color_range_image().data());
+  if (_in.has_particle_scatter_ratio())
+    out.SetScatterRatio(_in.particle_scatter_ratio().data());
 
   for (int i = 0; i < _in.header().data_size(); ++i)
   {
@@ -1682,10 +1622,6 @@ sdf::ParticleEmitter ignition::gazebo::convert(const msgs::ParticleEmitter &_in)
     {
       out.SetTopic(data.value(0));
     }
-    else if (data.key() == "particle_scatter_ratio" && data.value_size() > 0)
-    {
-      out.SetScatterRatio(std::stof(data.value(0)));
-    }
   }
 
   return out;
