@@ -53,6 +53,8 @@
 #include "ignition/gazebo/components/World.hh"
 #include "ignition/gazebo/SdfEntityCreator.hh"
 
+#include "../test/helpers/EnvTestFixture.hh"
+
 using namespace ignition;
 using namespace gazebo;
 
@@ -66,12 +68,8 @@ class EntityCompMgrTest : public gazebo::EntityComponentManager
 };
 
 /////////////////////////////////////////////////
-class SdfEntityCreatorTest : public ::testing::Test
+class SdfEntityCreatorTest : public InternalFixture<::testing::Test>
 {
-  public: void SetUp() override
-  {
-    ignition::common::Console::SetVerbosity(4);
-  }
   public: EntityCompMgrTest ecm;
   public: EventManager evm;
 };
@@ -817,9 +815,9 @@ TEST_F(SdfEntityCreatorTest, CreateLights)
       EXPECT_NE(nullptr, _geometry->Data().SphereShape());
       EXPECT_DOUBLE_EQ(0.5, _geometry->Data().SphereShape()->Radius());
 
-      EXPECT_EQ(math::Color(0.3, 0.3, 0.3), _material->Data().Ambient());
-      EXPECT_EQ(math::Color(0.3, 0.3, 0.3), _material->Data().Diffuse());
-      EXPECT_EQ(math::Color(0.3, 0.3, 0.3), _material->Data().Specular());
+      EXPECT_EQ(math::Color(0.3f, 0.3f, 0.3f), _material->Data().Ambient());
+      EXPECT_EQ(math::Color(0.3f, 0.3f, 0.3f), _material->Data().Diffuse());
+      EXPECT_EQ(math::Color(0.3f, 0.3f, 0.3f), _material->Data().Specular());
       return true;
     });
 
