@@ -21,7 +21,6 @@
 #include <ignition/common/Console.hh>
 #include <ignition/fuel_tools/ClientConfig.hh>
 #include <ignition/fuel_tools/Interface.hh>
-#include <ignition/utilities/ExtraTestMacros.hh>
 #include <sdf/Model.hh>
 #include <sdf/Root.hh>
 #include <sdf/sdf.hh>
@@ -50,17 +49,22 @@ using namespace gazebo;
 
 /////////////////////////////////////////////////
 /// \breif Checks if elemA is a subset of elemB
-static bool isSubset(const sdf::ElementPtr &_elemA,
+static testing::AssertionResult isSubset(const sdf::ElementPtr &_elemA,
                      const sdf::ElementPtr &_elemB)
 {
   if (_elemA->GetName() != _elemB->GetName())
   {
-    return false;
+    return testing::AssertionFailure()
+           << "Mismatch in element name: '" << _elemA->GetName() << "' vs '"
+           << _elemB->GetName() << "'";
   }
 
   if (_elemA->GetAttributeCount() != _elemB->GetAttributeCount())
   {
-    return false;
+    return testing::AssertionFailure()
+           << "Mismatch in attribute count for " << _elemA->GetName() << ": "
+           << _elemA->GetAttributeCount() << " vs "
+           << _elemB->GetAttributeCount();
   }
 
   // Compare attributes
@@ -70,11 +74,17 @@ static bool isSubset(const sdf::ElementPtr &_elemA,
     sdf::ParamPtr attrB = _elemB->GetAttribute(attrA->GetKey());
     if (attrA->GetTypeName() != attrB->GetTypeName())
     {
-      return false;
+      return testing::AssertionFailure()
+             << "Mismatch in attribute type for " << _elemA->GetName() << "/[@"
+             << attrA->GetKey() << "]: '" << attrA->GetTypeName() << "' vs '"
+             << attrB->GetTypeName() << "'";
     }
     if (attrA->GetAsString() != attrB->GetAsString())
     {
-      return false;
+      return testing::AssertionFailure()
+             << "Mismatch in attribute as string for " << _elemA->GetName()
+             << "/[@" << attrA->GetKey() << "]: '" << attrA->GetAsString()
+             << "' vs '" << attrB->GetAsString() << "'";
     }
   }
   // Compare values
@@ -84,11 +94,72 @@ static bool isSubset(const sdf::ElementPtr &_elemA,
     {
       sdf::ParamPtr valB = _elemB->GetValue();
       if (nullptr == valB)
-        return false;
+      {
+        return testing::AssertionFailure()
+               << "Value of " << _elemB->GetName() << " null";
+      }
       if (valA->GetTypeName() != valB->GetTypeName())
-        return false;
-      if (valA->GetAsString() != valB->GetAsString())
-        return false;
+      {
+        return testing::AssertionFailure()
+               << "Mismatch in value type for " << _elemA->GetName() << ": '"
+               << valA->GetTypeName() << "' vs '" << valB->GetTypeName() << "'";
+      }
+      if (valA->GetTypeName() == "pose")
+      {
+        math::Pose3d poseA, poseB;
+        valA->Get(poseA);
+        valA->Get(poseB);
+
+        if (poseA != poseB)
+        {
+          return testing::AssertionFailure()
+                 << "Mismatch in value as Pose: '" << poseA << "' vs '" << poseB
+                 << "'";
+        }
+      }
+      else if (valA->GetTypeName() == "double")
+      {
+        double dblA, dblB;
+        valA->Get(dblA);
+        valB->Get(dblB);
+        if (!math::equal(dblA, dblB))
+        {
+          return testing::AssertionFailure()
+                 << "Mismatch in value as double: '" << dblA << "' vs '"
+                 << dblB << "'";
+        }
+      }
+      else if (valA->GetTypeName() == "float")
+      {
+        float fltA, fltB;
+        valA->Get(fltA);
+        valB->Get(fltB);
+        if (!math::equal(fltA, fltB))
+        {
+          return testing::AssertionFailure()
+                 << "Mismatch in value as float: '" << fltA << "' vs '"
+                 << fltB << "'";
+        }
+      }
+      else if (valA->GetTypeName() == "bool")
+      {
+        bool boolA, boolB;
+        valA->Get(boolA);
+        valB->Get(boolB);
+        if (boolA != boolB)
+        {
+          return testing::AssertionFailure()
+                 << "Mismatch in value as bool: '" << boolA << "' vs '"
+                 << boolB << "'";
+        }
+
+      }
+      else if (valA->GetAsString() != valB->GetAsString())
+      {
+        return testing::AssertionFailure()
+          << "Mismatch in value as string: '" << valA->GetAsString()
+          << "' vs '" << valB->GetAsString() << "'";
+      }
     }
   }
 
@@ -113,10 +184,35 @@ static bool isSubset(const sdf::ElementPtr &_elemA,
     }
 
     if (!result)
-      return false;
+    {
+      // Ignore missing pose values if the pose is zero.
+      sdf::ParamPtr childValA = childElemA->GetValue();
+      if (childValA->GetTypeName() == "pose")
+      {
+        math::Pose3d childValPose;
+        childValA->Get(childValPose);
+        if (childValPose == math::Pose3d::Zero)
+          return testing::AssertionSuccess();
+      }
+      else if (childValA->GetTypeName() == "bool")
+      {
+        bool childValBool;
+        childValA->Get(childValBool);
+        if (!childValBool && (childElemA->GetName() == "static" ||
+            childElemA->GetName() == "self_collide" ||
+            childElemA->GetName() == "enable_wind" ))
+        {
+          return testing::AssertionSuccess();
+        }
+      }
+
+      return testing::AssertionFailure()
+             << "No matching child element in element B for child element '"
+             << childElemA->GetName() << "' in element A";
+    }
   }
 
-  return true;
+  return testing::AssertionSuccess();
 }
 
 /////////////////////////////////////////////////
@@ -125,15 +221,15 @@ TEST(CompareElements, CompareWithDuplicateElements)
   const std::string m1Sdf = R"(
   <sdf version="1.7">
     <model name="M1">
-      <pose>0 0 0 0 0 0 0</pose>
+      <pose>1 0 0 0 0 0</pose>
     </model>
   </sdf>
   )";
   const std::string m1CompTestSdf = R"(
   <sdf version="1.7">
     <model name="M1">
-      <pose>0 0 0 0 0 0 0</pose>
-      <pose>0 0 0 0 0 0 0</pose>
+      <pose>1 0 0 0 0 0</pose>
+      <pose>0 1 0 0 0 0</pose>
     </model>
   </sdf>
   )";
@@ -233,7 +329,7 @@ class ModelElementFixture : public ElementUpdateFixture
 
     auto elem = std::make_shared<sdf::Element>();
     sdf::initFile("model.sdf", elem);
-    updateModelElement(elem, this->ecm, model);
+    EXPECT_TRUE(updateModelElement(elem, this->ecm, model));
     return elem;
   }
 
@@ -547,7 +643,7 @@ TEST_F(ElementUpdateFixture, WorldWithModelsIncludedNotExpanded)
 TEST_F(ElementUpdateFixture, WorldWithModelsIncludedWithInvalidUris)
 {
   const std::string goodUri =
-      "https://fuel.ignitionrobotics.org/1.0/OpenRobotics/models/Backpack/2";
+      "https://fuel.ignitionrobotics.org/1.0/OpenRobotics/models/Backpack/2/";
 
   // These are URIs that are potentially problematic.
   const std::vector<std::string> fuelUris = {
@@ -796,9 +892,7 @@ TEST_F(ElementUpdateFixture, WorldWithModelsExpandedWithOneIncluded)
 }
 
 /////////////////////////////////////////////////
-// See https://github.com/ignitionrobotics/ign-gazebo/issues/1175
-TEST_F(ElementUpdateFixture,
-    IGN_UTILS_TEST_DISABLED_ON_WIN32(WorldWithModelsUsingRelativeResourceURIs))
+TEST_F(ElementUpdateFixture, WorldWithModelsUsingRelativeResourceURIs)
 {
   const auto includeUri = std::string("file://") + PROJECT_SOURCE_PATH +
                           "/test/worlds/models/relative_resource_uri";
@@ -881,6 +975,76 @@ TEST_F(GenerateWorldFixture, ModelsInline)
   }
 }
 
+/////////////////////////////////////////////////
+TEST_F(GenerateWorldFixture, PoseWithAttributes)
+{
+  const auto includeUri = std::string("file://") + PROJECT_SOURCE_PATH +
+                          "/test/worlds/models/relative_resource_uri";
+
+  std::string worldSdf = R"(
+<?xml version="1.0" ?>
+<sdf version="1.9">
+  <world name="test_pose_attributes">
+    <include>
+      <uri>)" + includeUri + R"(</uri>
+      <pose degrees="true">1 2 3 90 0 0</pose>
+      <name>model1</name>
+    </include>
+    <include>
+      <uri>)" + includeUri + R"(</uri>
+      <pose rotation_format="quat_xyzw">1 2 3 0 0 0 1</pose>
+      <name>model2</name>
+    </include>
+  </world>
+</sdf>
+  )";
+
+  this->LoadWorldString(worldSdf);
+  Entity worldEntity = this->ecm.EntityByComponents(components::World());
+
+  auto testPoses = [](const std::string &_worldStr)
+  {
+    sdf::Root newRoot;
+    sdf::Errors errors = newRoot.LoadSdfString(_worldStr);
+    EXPECT_TRUE(errors.empty()) << errors;
+    auto newWorld = newRoot.WorldByIndex(0);
+    ASSERT_NE(nullptr, newWorld);
+    {
+      auto model = newWorld->ModelByIndex(0);
+      ASSERT_NE(nullptr, model);
+      // Check that the generated element has the new pose
+      EXPECT_EQ(math::Pose3d(1, 2, 3, IGN_PI_2, 0, 0), model->RawPose());
+    }
+    {
+      auto model = newWorld->ModelByIndex(1);
+      ASSERT_NE(nullptr, model);
+      // Check that the generated element has the new pose
+      EXPECT_EQ(math::Pose3d(1, 2, 3, 0, 0, 0), model->RawPose());
+    }
+  };
+
+  // Test with models included models expanded
+  {
+    this->sdfGenConfig.mutable_global_entity_gen_config()
+      ->mutable_expand_include_tags()
+      ->set_data(true);
+
+    auto worldStr = sdf_generator::generateWorld(
+        this->ecm, worldEntity, this->includeUriMap, this->sdfGenConfig);
+    ASSERT_TRUE(worldStr.has_value());
+    SCOPED_TRACE("Included models expanded");
+    testPoses(*worldStr);
+  }
+
+  // Test with models included models not expanded
+  {
+    auto worldStr = sdf_generator::generateWorld(this->ecm, worldEntity);
+    ASSERT_TRUE(worldStr.has_value());
+    SCOPED_TRACE("Included models not expanded");
+    testPoses(*worldStr);
+  }
+}
+
 /////////////////////////////////////////////////
 /// Main
 int main(int _argc, char **_argv)
