@@ -21,7 +21,6 @@
 #include <ignition/common/Console.hh>
 #include <ignition/common/Util.hh>
 #include <ignition/transport/Node.hh>
-#include <ignition/utilities/ExtraTestMacros.hh>
 #include <sdf/Box.hh>
 #include <sdf/Capsule.hh>
 #include <sdf/Cylinder.hh>
@@ -57,6 +56,7 @@
 #include "ignition/gazebo/Events.hh"
 #include "ignition/gazebo/Util.hh"
 #include "ignition/gazebo/config.hh"
+
 #include "../test/helpers/EnvTestFixture.hh"
 #include "SimulationRunner.hh"
 
@@ -1073,7 +1073,7 @@ TEST_P(SimulationRunnerTest, Time)
   EXPECT_EQ(0u, runner.CurrentInfo().iterations);
   EXPECT_EQ(0ms, runner.CurrentInfo().simTime);
   EXPECT_EQ(0ms, runner.CurrentInfo().dt);
-  EXPECT_EQ(0ms, runner.UpdatePeriod());
+  EXPECT_EQ(1ms, runner.UpdatePeriod());
   EXPECT_EQ(1ms, runner.StepSize());
 
   runner.SetPaused(false);
@@ -1086,7 +1086,7 @@ TEST_P(SimulationRunnerTest, Time)
   EXPECT_EQ(100u, runner.CurrentInfo().iterations);
   EXPECT_EQ(100ms, runner.CurrentInfo().simTime);
   EXPECT_EQ(1ms, runner.CurrentInfo().dt);
-  EXPECT_EQ(0ms, runner.UpdatePeriod());
+  EXPECT_EQ(1ms, runner.UpdatePeriod());
   EXPECT_EQ(1ms, runner.StepSize());
 
   int sleep = 0;
@@ -1107,7 +1107,7 @@ TEST_P(SimulationRunnerTest, Time)
   EXPECT_EQ(200u, runner.CurrentInfo().iterations);
   EXPECT_EQ(300ms, runner.CurrentInfo().simTime);
   EXPECT_EQ(2ms, runner.CurrentInfo().dt);
-  EXPECT_EQ(0ms, runner.UpdatePeriod());
+  EXPECT_EQ(1ms, runner.UpdatePeriod());
   EXPECT_EQ(2ms, runner.StepSize());
 
   sleep = 0;
@@ -1127,7 +1127,7 @@ TEST_P(SimulationRunnerTest, Time)
   EXPECT_EQ(200u, runner.CurrentInfo().iterations);
   EXPECT_EQ(300ms, runner.CurrentInfo().simTime);
   EXPECT_EQ(2ms, runner.CurrentInfo().dt);
-  EXPECT_EQ(0ms, runner.UpdatePeriod());
+  EXPECT_EQ(1ms, runner.UpdatePeriod());
   EXPECT_EQ(2ms, runner.StepSize());
 
   // Verify info published to /clock topic
@@ -1145,7 +1145,7 @@ TEST_P(SimulationRunnerTest, Time)
   EXPECT_EQ(500ms, runner.CurrentInfo().simTime)
     << runner.CurrentInfo().simTime.count();
   EXPECT_EQ(2ms, runner.CurrentInfo().dt);
-  EXPECT_EQ(0ms, runner.UpdatePeriod());
+  EXPECT_EQ(1ms, runner.UpdatePeriod());
   EXPECT_EQ(2ms, runner.StepSize());
 
   sleep = 0;
@@ -1183,8 +1183,7 @@ TEST_P(SimulationRunnerTest, Time)
 }
 
 /////////////////////////////////////////////////
-// See https://github.com/ignitionrobotics/ign-gazebo/issues/1175
-TEST_P(SimulationRunnerTest, IGN_UTILS_TEST_DISABLED_ON_WIN32(LoadPlugins) )
+TEST_P(SimulationRunnerTest, LoadPlugins)
 {
   // Load SDF file
   sdf::Root root;
@@ -1271,8 +1270,7 @@ TEST_P(SimulationRunnerTest, IGN_UTILS_TEST_DISABLED_ON_WIN32(LoadPlugins) )
 }
 
 /////////////////////////////////////////////////
-TEST_P(SimulationRunnerTest,
-       IGN_UTILS_TEST_DISABLED_ON_WIN32(LoadServerNoPlugins) )
+TEST_P(SimulationRunnerTest, LoadServerNoPlugins)
 {
   sdf::Root rootWithout;
   rootWithout.Load(common::joinPaths(PROJECT_SOURCE_PATH,
@@ -1294,8 +1292,7 @@ TEST_P(SimulationRunnerTest,
 }
 
 /////////////////////////////////////////////////
-TEST_P(SimulationRunnerTest,
-       IGN_UTILS_TEST_DISABLED_ON_WIN32(LoadServerConfigPlugins) )
+TEST_P(SimulationRunnerTest, LoadServerConfigPlugins)
 {
   sdf::Root rootWithout;
   rootWithout.Load(common::joinPaths(PROJECT_SOURCE_PATH,
@@ -1395,8 +1392,7 @@ TEST_P(SimulationRunnerTest,
 }
 
 /////////////////////////////////////////////////
-TEST_P(SimulationRunnerTest,
-       IGN_UTILS_TEST_DISABLED_ON_WIN32(LoadPluginsDefault) )
+TEST_P(SimulationRunnerTest, LoadPluginsDefault)
 {
   sdf::Root rootWithout;
   rootWithout.Load(common::joinPaths(PROJECT_SOURCE_PATH,
@@ -1417,8 +1413,7 @@ TEST_P(SimulationRunnerTest,
 }
 
 /////////////////////////////////////////////////
-TEST_P(SimulationRunnerTest,
-       IGN_UTILS_TEST_DISABLED_ON_WIN32(LoadPluginsEvent) )
+TEST_P(SimulationRunnerTest, LoadPluginsEvent)
 {
   // Load SDF file without plugins
   sdf::Root rootWithout;
@@ -1538,7 +1533,7 @@ TEST_P(SimulationRunnerTest, GuiInfo)
 
   auto plugin = res.plugin(0);
   EXPECT_EQ("3D View", plugin.name());
-  EXPECT_EQ("GzScene3D", plugin.filename());
+  EXPECT_EQ("MinimalScene", plugin.filename());
   EXPECT_NE(plugin.innerxml().find("<ignition-gui>"), std::string::npos);
   EXPECT_NE(plugin.innerxml().find("<ambient_light>"), std::string::npos);
   EXPECT_EQ(plugin.innerxml().find("<service>"), std::string::npos);
