@@ -291,13 +291,8 @@ void VisualizeLidar::Update(const UpdateInfo &,
           for (auto child : children)
           {
             std::string nextstring = lidarURIVec[i+1];
-            auto comp = _ecm.Component<components::Name>(child);
-            if (!comp)
-            {
-              continue;
-            }
             std::string childname = std::string(
-                            comp->Data());
+                            _ecm.Component<components::Name>(child)->Data());
             if (nextstring.compare(childname) == 0)
             {
               parent = child;
@@ -369,6 +364,13 @@ void VisualizeLidar::UpdateType(int _type)
   this->dataPtr->lidar->SetType(this->dataPtr->visualType);
 }
 
+//////////////////////////////////////////////////
+void VisualizeLidar::UpdateSize(int _size)
+{
+  std::lock_guard<std::mutex> lock(this->dataPtr->serviceMutex);
+  this->dataPtr->lidar->SetSize(_size);
+}
+
 //////////////////////////////////////////////////
 void VisualizeLidar::OnTopic(const QString &_topicName)
 {
