@@ -17,8 +17,8 @@
 
 #include "LinearBatteryPlugin.hh"
 
-#include <gz/msgs/battery_state.pb.h>
-#include <gz/msgs/boolean.pb.h>
+#include <ignition/msgs/battery_state.pb.h>
+#include <ignition/msgs/boolean.pb.h>
 
 #include <algorithm>
 #include <atomic>
@@ -27,29 +27,29 @@
 #include <string>
 #include <vector>
 
-#include <gz/common/Battery.hh>
-#include <gz/common/Profiler.hh>
-#include <gz/common/Util.hh>
+#include <ignition/common/Battery.hh>
+#include <ignition/common/Profiler.hh>
+#include <ignition/common/Util.hh>
 
-#include <gz/plugin/Register.hh>
-#include <gz/transport/Node.hh>
+#include <ignition/plugin/Register.hh>
+#include <ignition/transport/Node.hh>
 
 #include <sdf/Element.hh>
 #include <sdf/Physics.hh>
 #include <sdf/Root.hh>
 #include <sdf/World.hh>
 
-#include "gz/sim/components/BatterySoC.hh"
-#include "gz/sim/components/Joint.hh"
-#include "gz/sim/components/JointForceCmd.hh"
-#include "gz/sim/components/JointVelocityCmd.hh"
-#include "gz/sim/components/Name.hh"
-#include "gz/sim/components/ParentEntity.hh"
-#include "gz/sim/components/World.hh"
-#include "gz/sim/Model.hh"
+#include "ignition/gazebo/components/BatterySoC.hh"
+#include "ignition/gazebo/components/Joint.hh"
+#include "ignition/gazebo/components/JointForceCmd.hh"
+#include "ignition/gazebo/components/JointVelocityCmd.hh"
+#include "ignition/gazebo/components/Name.hh"
+#include "ignition/gazebo/components/ParentEntity.hh"
+#include "ignition/gazebo/components/World.hh"
+#include "ignition/gazebo/Model.hh"
 
-using namespace gz;
-using namespace gz::sim;
+using namespace ignition;
+using namespace gazebo;
 using namespace systems;
 
 class ignition::gazebo::systems::LinearBatteryPluginPrivate
@@ -63,11 +63,11 @@ class ignition::gazebo::systems::LinearBatteryPluginPrivate
 
   /// \brief Callback executed to start recharging.
   /// \param[in] _req This value should be true.
-  public: void OnEnableRecharge(const msgs::Boolean &_req);
+  public: void OnEnableRecharge(const ignition::msgs::Boolean &_req);
 
   /// \brief Callback executed to stop recharging.
   /// \param[in] _req This value should be true.
-  public: void OnDisableRecharge(const msgs::Boolean &_req);
+  public: void OnDisableRecharge(const ignition::msgs::Boolean &_req);
 
   /// \brief Name of model, only used for printing warning when battery drains.
   public: std::string modelName;
@@ -297,16 +297,28 @@ void LinearBatteryPlugin::Configure(const Entity &_entity,
         "/battery/" + _sdf->Get<std::string>("battery_name") +
         "/recharge/stop";
 
-      this->dataPtr->node.Advertise(enableRechargeTopic,
+      auto validEnableRechargeTopic = transport::TopicUtils::AsValidTopic(
+          enableRechargeTopic);
+      auto validDisableRechargeTopic = transport::TopicUtils::AsValidTopic(
+          disableRechargeTopic);
+      if (validEnableRechargeTopic.empty() || validDisableRechargeTopic.empty())
+      {
+        ignerr << "Failed to create valid topics. Not valid: ["
+               << enableRechargeTopic << "] and [" << disableRechargeTopic
+               << "]" << std::endl;
+        return;
+      }
+
+      this->dataPtr->node.Advertise(validEnableRechargeTopic,
         &LinearBatteryPluginPrivate::OnEnableRecharge, this->dataPtr.get());
-      this->dataPtr->node.Advertise(disableRechargeTopic,
+      this->dataPtr->node.Advertise(validDisableRechargeTopic,
         &LinearBatteryPluginPrivate::OnDisableRecharge, this->dataPtr.get());
 
       if (_sdf->HasElement("recharge_by_topic"))
       {
-        this->dataPtr->node.Subscribe(enableRechargeTopic,
+        this->dataPtr->node.Subscribe(validEnableRechargeTopic,
           &LinearBatteryPluginPrivate::OnEnableRecharge, this->dataPtr.get());
-        this->dataPtr->node.Subscribe(disableRechargeTopic,
+        this->dataPtr->node.Subscribe(validDisableRechargeTopic,
           &LinearBatteryPluginPrivate::OnDisableRecharge, this->dataPtr.get());
       }
     }
@@ -338,10 +350,19 @@ void LinearBatteryPlugin::Configure(const Entity &_entity,
   // Setup battery state topic
   std::string stateTopic{"/model/" + this->dataPtr->model.Name(_ecm) +
     "/battery/" + this->dataPtr->battery->Name() + "/state"};
+
+  auto validStateTopic = transport::TopicUtils::AsValidTopic(stateTopic);
+  if (validStateTopic.empty())
+  {
+    ignerr << "Failed to create valid state topic ["
+           << stateTopic << "]" << std::endl;
+    return;
+  }
+
   transport::AdvertiseMessageOptions opts;
   opts.SetMsgsPerSec(50);
   this->dataPtr->statePub = this->dataPtr->node.Advertise<msgs::BatteryState>(
-    stateTopic, opts);
+    validStateTopic, opts);
 }
 
 /////////////////////////////////////////////////
@@ -360,7 +381,7 @@ double LinearBatteryPluginPrivate::StateOfCharge() const
 
 //////////////////////////////////////////////////
 void LinearBatteryPluginPrivate::OnEnableRecharge(
-  const msgs::Boolean &/*_req*/)
+  const ignition::msgs::Boolean &/*_req*/)
 {
   igndbg << "Request for start charging received" << std::endl;
   this->startCharging = true;
@@ -368,7 +389,7 @@ void LinearBatteryPluginPrivate::OnEnableRecharge(
 
 //////////////////////////////////////////////////
 void LinearBatteryPluginPrivate::OnDisableRecharge(
-  const msgs::Boolean &/*_req*/)
+  const ignition::msgs::Boolean &/*_req*/)
 {
   igndbg << "Request for stop charging received" << std::endl;
   this->startCharging = false;
@@ -376,8 +397,8 @@ void LinearBatteryPluginPrivate::OnDisableRecharge(
 
 //////////////////////////////////////////////////
 void LinearBatteryPlugin::PreUpdate(
-  const UpdateInfo &/*_info*/,
-  EntityComponentManager &_ecm)
+  const ignition::gazebo::UpdateInfo &/*_info*/,
+  ignition::gazebo::EntityComponentManager &_ecm)
 {
   IGN_PROFILE("LinearBatteryPlugin::PreUpdate");
   this->dataPtr->startDraining = false;
@@ -608,15 +629,11 @@ double LinearBatteryPlugin::OnUpdateVoltage(
 }
 
 IGNITION_ADD_PLUGIN(LinearBatteryPlugin,
-                    System,
+                    ignition::gazebo::System,
                     LinearBatteryPlugin::ISystemConfigure,
                     LinearBatteryPlugin::ISystemPreUpdate,
                     LinearBatteryPlugin::ISystemUpdate,
                     LinearBatteryPlugin::ISystemPostUpdate)
 
-IGNITION_ADD_PLUGIN_ALIAS(LinearBatteryPlugin,
-  "gz::sim::systems::LinearBatteryPlugin")
-
-// TODO(CH3): Deprecated, remove on version 8
 IGNITION_ADD_PLUGIN_ALIAS(LinearBatteryPlugin,
   "ignition::gazebo::systems::LinearBatteryPlugin")
