@@ -22,16 +22,14 @@
 #include <ignition/msgs/entity_factory.pb.h>
 #include <ignition/msgs/light.pb.h>
 #include <ignition/msgs/pose.pb.h>
-#include <ignition/msgs/pose_v.pb.h>
 #include <ignition/msgs/physics.pb.h>
 #include <ignition/msgs/visual.pb.h>
-#include <ignition/msgs/wheel_slip_parameters_cmd.pb.h>
 
 #include <string>
 #include <utility>
-#include <unordered_set>
 #include <vector>
 
+#include <ignition/math/SphericalCoordinates.hh>
 #include <ignition/msgs/Utility.hh>
 
 #include <sdf/Physics.hh>
@@ -44,8 +42,6 @@
 
 #include "ignition/common/Profiler.hh"
 
-#include "ignition/gazebo/components/Collision.hh"
-#include "ignition/gazebo/components/Joint.hh"
 #include "ignition/gazebo/components/Light.hh"
 #include "ignition/gazebo/components/LightCmd.hh"
 #include "ignition/gazebo/components/Link.hh"
@@ -55,18 +51,16 @@
 #include "ignition/gazebo/components/Pose.hh"
 #include "ignition/gazebo/components/PoseCmd.hh"
 #include "ignition/gazebo/components/PhysicsCmd.hh"
-#include "ignition/gazebo/components/Visual.hh"
+#include "ignition/gazebo/components/SphericalCoordinates.hh"
 #include "ignition/gazebo/components/World.hh"
 #include "ignition/gazebo/Conversions.hh"
 #include "ignition/gazebo/EntityComponentManager.hh"
-#include "ignition/gazebo/Model.hh"
 #include "ignition/gazebo/SdfEntityCreator.hh"
-#include "ignition/gazebo/Util.hh"
+#include "ignition/gazebo/World.hh"
 #include "ignition/gazebo/components/ContactSensorData.hh"
 #include "ignition/gazebo/components/ContactSensor.hh"
 #include "ignition/gazebo/components/Sensor.hh"
 #include "ignition/gazebo/components/VisualCmd.hh"
-#include "ignition/gazebo/components/WheelSlipCmd.hh"
 
 using namespace ignition;
 using namespace gazebo;
@@ -79,6 +73,74 @@ namespace gazebo
 inline namespace IGNITION_GAZEBO_VERSION_NAMESPACE {
 namespace systems
 {
+
+/// \brief Helper function to get an entity from an entity message.
+///
+/// \TODO(anyone) Move to Util.hh and generalize for all entities,
+/// not only top level
+///
+/// The message is used as follows:
+///
+///     if id not null
+///       use id
+///     else if name not null and type not null
+///       use name + type
+///     else
+///       error
+///     end
+/// \param[in] _ecm Entity component manager
+/// \param[in] _msg Entity message
+/// \return Entity ID, or kNullEntity if a matching entity couldn't be
+/// found.
+Entity topLevelEntityFromMessage(const EntityComponentManager &_ecm,
+    const msgs::Entity &_msg)
+{
+  if (_msg.id() != kNullEntity)
+  {
+    return _msg.id();
+  }
+
+  if (!_msg.name().empty() && _msg.type() != msgs::Entity::NONE)
+  {
+    Entity entity{kNullEntity};
+    if (_msg.type() == msgs::Entity::MODEL)
+    {
+      entity = _ecm.EntityByComponents(components::Model(),
+        components::Name(_msg.name()));
+    }
+    else if (_msg.type() == msgs::Entity::LIGHT)
+    {
+      entity = _ecm.EntityByComponents(
+        components::Name(_msg.name()));
+
+      auto lightComp = _ecm.Component<components::Light>(entity);
+      if (nullptr == lightComp)
+        entity = kNullEntity;
+    }
+    else
+    {
+      ignerr << "Failed to handle entity type [" << _msg.type() << "]"
+             << std::endl;
+    }
+    return entity;
+  }
+
+  ignerr << "Message missing either entity's ID or name + type" << std::endl;
+  return kNullEntity;
+}
+
+/// \brief Pose3d equality comparison function.
+/// \param[in] _a A pose to compare
+/// \param[in] _b Another pose to compare
+bool pose3Eql(const math::Pose3d &_a, const math::Pose3d &_b)
+{
+  return _a.Pos().Equal(_b.Pos(), 1e-6) &&
+    math::equal(_a.Rot().X(), _b.Rot().X(), 1e-6) &&
+    math::equal(_a.Rot().Y(), _b.Rot().Y(), 1e-6) &&
+    math::equal(_a.Rot().Z(), _b.Rot().Z(), 1e-6) &&
+    math::equal(_a.Rot().W(), _b.Rot().W(), 1e-6);
+}
+
 /// \brief This class is passed to every command and contains interfaces that
 /// can be shared among all commands. For example, all create and remove
 /// commands can use the `creator` object.
@@ -168,50 +230,7 @@ class LightCommand : public UserCommandBase
   public: std::function<bool(const msgs::Light &, const msgs::Light &)>
           lightEql { [](const msgs::Light &_a, const msgs::Light &_b)
             {
-              // todo(ahcorde) Use the field is_light_off in light.proto from
-              // Garden on.
-              auto getVisualizeVisual = [](const msgs::Light &_light) -> bool
-              {
-                bool visualizeVisual = true;
-                for (int i = 0; i < _light.header().data_size(); ++i)
-                {
-                  for (int j = 0;
-                      j < _light.header().data(i).value_size(); ++j)
-                  {
-                    if (_light.header().data(i).key() ==
-                        "visualizeVisual")
-                    {
-                      visualizeVisual = ignition::math::parseInt(
-                        _light.header().data(i).value(0));
-                    }
-                  }
-                }
-                return visualizeVisual;
-              };
-
-              // todo(ahcorde) Use the field is_light_off in light.proto from
-              // Garden on.
-              auto getIsLightOn = [](const msgs::Light &_light) -> bool
-              {
-                bool isLightOn = true;
-                for (int i = 0; i < _light.header().data_size(); ++i)
-                {
-                  for (int j = 0;
-                      j < _light.header().data(i).value_size(); ++j)
-                  {
-                    if (_light.header().data(i).key() ==
-                        "isLightOn")
-                    {
-                      isLightOn = ignition::math::parseInt(
-                        _light.header().data(i).value(0));
-                    }
-                  }
-                }
-                return isLightOn;
-               };
              return
-                getVisualizeVisual(_a) == getVisualizeVisual(_b) &&
-                getIsLightOn(_a) == getIsLightOn(_b) &&
                 _a.type() == _b.type() &&
                 _a.name() == _b.name() &&
                 math::equal(
@@ -276,19 +295,6 @@ class PoseCommand : public UserCommandBase
   public: bool Execute() final;
 };
 
-/// \brief Command to update an entity's pose transform.
-class PoseVectorCommand : public UserCommandBase
-{
-  /// \brief Constructor
-  /// \param[in] _msg pose_v message.
-  /// \param[in] _iface Pointer to user commands interface.
-  public: PoseVectorCommand(msgs::Pose_V *_msg,
-      std::shared_ptr<UserCommandsInterface> &_iface);
-
-  // Documentation inherited
-  public: bool Execute() final;
-};
-
 /// \brief Command to modify the physics parameters of a simulation.
 class PhysicsCommand : public UserCommandBase
 {
@@ -302,6 +308,19 @@ class PhysicsCommand : public UserCommandBase
   public: bool Execute() final;
 };
 
+/// \brief Command to modify the spherical coordinates of a simulation.
+class SphericalCoordinatesCommand : public UserCommandBase
+{
+  /// \brief Constructor
+  /// \param[in] _msg Message containing the new coordinates.
+  /// \param[in] _iface Pointer to user commands interface.
+  public: SphericalCoordinatesCommand(msgs::SphericalCoordinates *_msg,
+      std::shared_ptr<UserCommandsInterface> &_iface);
+
+  // Documentation inherited
+  public: bool Execute() final;
+};
+
 /// \brief Command to enable a collision component.
 class EnableCollisionCommand : public UserCommandBase
 {
@@ -385,48 +404,6 @@ class VisualCommand : public UserCommandBase
                   aMaterial.emissive().a(), bMaterial.emissive().a(), 1e-6f);
             }};
 };
-
-/// \brief Command to modify a wheel entity from simulation.
-class WheelSlipCommand : public UserCommandBase
-{
-  /// \brief Constructor
-  /// \param[in] _msg Message containing the wheel slip parameters.
-  /// \param[in] _iface Pointer to user commands interface.
-  public: WheelSlipCommand(msgs::WheelSlipParametersCmd *_msg,
-      std::shared_ptr<UserCommandsInterface> &_iface);
-
-  // Documentation inherited
-  public: bool Execute() final;
-
-  /// \brief WheelSlip equality comparision function
-  public: std::function<bool(
-    const msgs::WheelSlipParametersCmd &, const msgs::WheelSlipParametersCmd &)>
-          wheelSlipEql {
-            [](
-              const msgs::WheelSlipParametersCmd &_a,
-              const msgs::WheelSlipParametersCmd &_b)
-            {
-              return
-                (
-                  (
-                    _a.entity().id() != kNullEntity &&
-                    _a.entity().id() == _b.entity().id()
-                  ) ||
-                  (
-                    _a.entity().name() == _b.entity().name() &&
-                    _a.entity().type() == _b.entity().type()
-                  )
-                ) &&
-                math::equal(
-                  _a.slip_compliance_lateral(),
-                  _b.slip_compliance_lateral(),
-                  1e-6) &&
-                math::equal(
-                  _a.slip_compliance_longitudinal(),
-                  _b.slip_compliance_longitudinal(),
-                  1e-6);
-            }};
-};
 }
 }
 }
@@ -473,13 +450,6 @@ class ignition::gazebo::systems::UserCommandsPrivate
   /// \return True if successful.
   public: bool PoseService(const msgs::Pose &_req, msgs::Boolean &_res);
 
-  /// \brief Callback for pose_v service
-  /// \param[in] _req Request containing pose update of several entities.
-  /// \param[out] _res True if message successfully received and queued.
-  /// It does not mean that the entity will be successfully moved.
-  /// \return True if successful.
-  public: bool PoseVectorService(const msgs::Pose_V &_req, msgs::Boolean &_res);
-
   /// \brief Callback for physics service
   /// \param[in] _req Request containing updates to the physics parameters.
   /// \param[out] _res True if message successfully received and queued.
@@ -487,6 +457,14 @@ class ignition::gazebo::systems::UserCommandsPrivate
   /// \return True if successful.
   public: bool PhysicsService(const msgs::Physics &_req, msgs::Boolean &_res);
 
+  /// \brief Callback for spherical coordinates service
+  /// \param[in] _req Request containing updates to the spherical coordinates.
+  /// \param[in] _res True if message successfully received and queued.
+  /// It does not mean that the physics parameters will be successfully updated.
+  /// \return True if successful.
+  public: bool SphericalCoordinatesService(
+      const msgs::SphericalCoordinates &_req, msgs::Boolean &_res);
+
   /// \brief Callback for enable collision service
   /// \param[in] _req Request containing collision entity.
   /// \param[out] _res True if message successfully received and queued.
@@ -510,16 +488,6 @@ class ignition::gazebo::systems::UserCommandsPrivate
   /// \return True if successful.
   public: bool VisualService(const msgs::Visual &_req, msgs::Boolean &_res);
 
-  /// \brief Callback for wheel slip service
-  /// \param[in] _req Request containing wheel slip parameter updates of an
-  ///  entity.
-  /// \param[out] _res True if message sucessfully received and queued.
-  /// It does not mean that the wheel slip parameters will be successfully
-  /// updated.
-  /// \return True if successful.
-  public: bool WheelSlipService(
-    const msgs::WheelSlipParametersCmd &_req, msgs::Boolean &_res);
-
   /// \brief Queue of commands pending execution.
   public: std::vector<std::unique_ptr<UserCommandBase>> pendingCmds;
 
@@ -533,26 +501,6 @@ class ignition::gazebo::systems::UserCommandsPrivate
   public: std::mutex pendingMutex;
 };
 
-/// \brief Pose3d equality comparison function.
-/// \param[in] _a A pose to compare
-/// \param[in] _b Another pose to compare
-bool pose3Eql(const math::Pose3d &_a, const math::Pose3d &_b)
-{
-  return _a.Pos().Equal(_b.Pos(), 1e-6) &&
-    math::equal(_a.Rot().X(), _b.Rot().X(), 1e-6) &&
-    math::equal(_a.Rot().Y(), _b.Rot().Y(), 1e-6) &&
-    math::equal(_a.Rot().Z(), _b.Rot().Z(), 1e-6) &&
-    math::equal(_a.Rot().W(), _b.Rot().W(), 1e-6);
-}
-
-/// \brief Update pose for a specific pose message
-/// \param[in] _req Message containing new pose
-/// \param[in] _iface Pointer to user commands interface.
-/// \return True if successful.
-bool updatePose(
-  const msgs::Pose &_req,
-  std::shared_ptr<UserCommandsInterface> _iface);
-
 //////////////////////////////////////////////////
 UserCommands::UserCommands() : System(),
     dataPtr(std::make_unique<UserCommandsPrivate>())
@@ -646,14 +594,6 @@ void UserCommands::Configure(const Entity &_entity,
 
   ignmsg << "Pose service on [" << poseService << "]" << std::endl;
 
-  // Pose vector service
-  std::string poseVectorService{
-    "/world/" + worldName + "/set_pose_vector"};
-  this->dataPtr->node.Advertise(poseVectorService,
-      &UserCommandsPrivate::PoseVectorService, this->dataPtr.get());
-
-  ignmsg << "Pose service on [" << poseVectorService << "]" << std::endl;
-
   // Light service
   std::string lightService{"/world/" + validWorldName + "/light_config"};
   this->dataPtr->node.Advertise(lightService,
@@ -669,6 +609,15 @@ void UserCommands::Configure(const Entity &_entity,
 
   ignmsg << "Physics service on [" << physicsService << "]" << std::endl;
 
+  // Spherical coordinates service
+  std::string sphericalCoordinatesService{"/world/" + validWorldName +
+      "/set_spherical_coordinates"};
+  this->dataPtr->node.Advertise(sphericalCoordinatesService,
+      &UserCommandsPrivate::SphericalCoordinatesService, this->dataPtr.get());
+
+  ignmsg << "SphericalCoordinates service on [" << sphericalCoordinatesService
+         << "]" << std::endl;
+
   // Enable collision service
   std::string enableCollisionService{
     "/world/" + validWorldName + "/enable_collision"};
@@ -694,14 +643,6 @@ void UserCommands::Configure(const Entity &_entity,
       &UserCommandsPrivate::VisualService, this->dataPtr.get());
 
   ignmsg << "Material service on [" << visualService << "]" << std::endl;
-
-  // Wheel slip service
-  std::string wheelSlipService
-      {"/world/" + validWorldName + "/wheel_slip"};
-  this->dataPtr->node.Advertise(wheelSlipService,
-      &UserCommandsPrivate::WheelSlipService, this->dataPtr.get());
-
-  ignmsg << "Material service on [" << wheelSlipService << "]" << std::endl;
 }
 
 //////////////////////////////////////////////////
@@ -832,25 +773,6 @@ bool UserCommandsPrivate::PoseService(const msgs::Pose &_req,
   return true;
 }
 
-//////////////////////////////////////////////////
-bool UserCommandsPrivate::PoseVectorService(const msgs::Pose_V &_req,
-    msgs::Boolean &_res)
-{
-  // Create command and push it to queue
-  auto msg = _req.New();
-  msg->CopyFrom(_req);
-  auto cmd = std::make_unique<PoseVectorCommand>(msg, this->iface);
-
-  // Push to pending
-  {
-    std::lock_guard<std::mutex> lock(this->pendingMutex);
-    this->pendingCmds.push_back(std::move(cmd));
-  }
-
-  _res.set_data(true);
-  return true;
-}
-
 //////////////////////////////////////////////////
 bool UserCommandsPrivate::EnableCollisionService(const msgs::Entity &_req,
     msgs::Boolean &_res)
@@ -926,14 +848,13 @@ bool UserCommandsPrivate::VisualService(const msgs::Visual &_req,
 }
 
 //////////////////////////////////////////////////
-bool UserCommandsPrivate::WheelSlipService(
-    const msgs::WheelSlipParametersCmd &_req,
-    msgs::Boolean &_res)
+bool UserCommandsPrivate::SphericalCoordinatesService(
+    const msgs::SphericalCoordinates &_req, msgs::Boolean &_res)
 {
   // Create command and push it to queue
   auto msg = _req.New();
   msg->CopyFrom(_req);
-  auto cmd = std::make_unique<WheelSlipCommand>(msg, this->iface);
+  auto cmd = std::make_unique<SphericalCoordinatesCommand>(msg, this->iface);
   // Push to pending
   {
     std::lock_guard<std::mutex> lock(this->pendingMutex);
@@ -1005,9 +926,41 @@ bool CreateCommand::Execute()
     }
     case msgs::EntityFactory::kCloneName:
     {
-      // TODO(louise) Implement clone
-      ignerr << "Cloning an entity is not yet supported." << std::endl;
-      return false;
+      auto validClone = false;
+      auto clonedEntity = kNullEntity;
+      auto entityToClone = this->iface->ecm->EntityByComponents(
+          components::Name(createMsg->clone_name()));
+      if (kNullEntity != entityToClone)
+      {
+        auto parentComp =
+          this->iface->ecm->Component<components::ParentEntity>(entityToClone);
+
+        // TODO(anyone) add better support for creating non-top level entities.
+        // For now, we will only clone top level entities
+        if (parentComp && parentComp->Data() == this->iface->worldEntity)
+        {
+          auto parentEntity = parentComp->Data();
+          clonedEntity = this->iface->ecm->Clone(entityToClone,
+              parentEntity, createMsg->name(), createMsg->allow_renaming());
+          validClone = kNullEntity != clonedEntity;
+        }
+      }
+
+      if (!validClone)
+      {
+        ignerr << "Request to clone an entity named ["
+          << createMsg->clone_name() << "] failed." << std::endl;
+        return false;
+      }
+
+      if (createMsg->has_pose())
+      {
+        // TODO(anyone) handle if relative_to is filled
+        auto pose = gazebo::convert<math::Pose3d>(createMsg->pose());
+        this->iface->ecm->SetComponentData<components::Pose>(clonedEntity,
+            pose);
+      }
+      return true;
     }
     default:
     {
@@ -1141,6 +1094,35 @@ bool CreateCommand::Execute()
     auto poseComp = this->iface->ecm->Component<components::Pose>(entity);
     *poseComp = components::Pose(msgs::Convert(createMsg->pose()));
   }
+  // Spherical coordinates
+  else if (createMsg->has_spherical_coordinates())
+  {
+    auto scComp = this->iface->ecm->Component<components::SphericalCoordinates>(
+        this->iface->worldEntity);
+    if (nullptr == scComp)
+    {
+      ignwarn << "Trying to create entity [" << desiredName
+              << "] with spherical coordinates, but world's spherical "
+              << "coordinates aren't set. Entity will be created at the world "
+              << "origin." << std::endl;
+    }
+    else
+    {
+      // deg to rad
+      math::Vector3d latLonEle{
+          IGN_DTOR(createMsg->spherical_coordinates().latitude_deg()),
+          IGN_DTOR(createMsg->spherical_coordinates().longitude_deg()),
+          createMsg->spherical_coordinates().elevation()};
+
+      auto pos = scComp->Data().PositionTransform(latLonEle,
+          math::SphericalCoordinates::SPHERICAL,
+          math::SphericalCoordinates::LOCAL2);
+
+      auto poseComp = this->iface->ecm->Component<components::Pose>(entity);
+      *poseComp = components::Pose({pos.X(), pos.Y(), pos.Z(), 0, 0,
+          IGN_DTOR(createMsg->spherical_coordinates().heading_deg())});
+    }
+  }
 
   igndbg << "Created entity [" << entity << "] named [" << desiredName << "]"
          << std::endl;
@@ -1165,42 +1147,7 @@ bool RemoveCommand::Execute()
     return false;
   }
 
-  Entity entity{kNullEntity};
-  if (removeMsg->id() != kNullEntity)
-  {
-    entity = removeMsg->id();
-  }
-  else if (!removeMsg->name().empty() &&
-      removeMsg->type() != msgs::Entity::NONE)
-  {
-    if (removeMsg->type() == msgs::Entity::MODEL)
-    {
-      entity = this->iface->ecm->EntityByComponents(components::Model(),
-        components::Name(removeMsg->name()));
-    }
-    else if (removeMsg->type() == msgs::Entity::LIGHT)
-    {
-      entity = this->iface->ecm->EntityByComponents(
-        components::Name(removeMsg->name()));
-
-      auto lightComp = this->iface->ecm->Component<components::Light>(entity);
-      if (nullptr == lightComp)
-        entity = kNullEntity;
-    }
-    else
-    {
-      ignerr << "Deleting entities of type [" << removeMsg->type()
-             << "] is not supported." << std::endl;
-      return false;
-    }
-  }
-  else
-  {
-    ignerr << "Remove command missing either entity's ID or name + type"
-           << std::endl;
-    return false;
-  }
-
+  auto entity = topLevelEntityFromMessage(*this->iface->ecm, *removeMsg);
   if (entity == kNullEntity)
   {
     ignerr << "Entity named [" << removeMsg->name() << "] of type ["
@@ -1318,51 +1265,6 @@ bool LightCommand::Execute()
   return true;
 }
 
-//////////////////////////////////////////////////
-bool updatePose(
-  const msgs::Pose &_poseMsg,
-  std::shared_ptr<UserCommandsInterface> _iface)
-{
-  // Check the name of the entity being spawned
-  std::string entityName = _poseMsg.name();
-  Entity entity = kNullEntity;
-  // TODO(anyone) Update pose message to use Entity, with default ID null
-  if (_poseMsg.id() != kNullEntity && _poseMsg.id() != 0)
-  {
-    entity = _poseMsg.id();
-  }
-  else if (!entityName.empty())
-  {
-    entity = _iface->ecm->EntityByComponents(components::Name(entityName),
-      components::ParentEntity(_iface->worldEntity));
-  }
-
-  if (!_iface->ecm->HasEntity(entity))
-  {
-    ignerr << "Unable to update the pose for entity id:[" << _poseMsg.id()
-           << "], name[" << entityName << "]" << std::endl;
-    return false;
-  }
-
-  auto poseCmdComp =
-    _iface->ecm->Component<components::WorldPoseCmd>(entity);
-  if (!poseCmdComp)
-  {
-    _iface->ecm->CreateComponent(
-        entity, components::WorldPoseCmd(msgs::Convert(_poseMsg)));
-  }
-  else
-  {
-    /// \todo(anyone) Moving an object is not captured in a log file.
-    auto state = poseCmdComp->SetData(msgs::Convert(_poseMsg), pose3Eql) ?
-        ComponentState::OneTimeChange :
-        ComponentState::NoChange;
-    _iface->ecm->SetChanged(entity, components::WorldPoseCmd::typeId,
-        state);
-  }
-  return true;
-}
-
 //////////////////////////////////////////////////
 PoseCommand::PoseCommand(msgs::Pose *_msg,
     std::shared_ptr<UserCommandsInterface> &_iface)
@@ -1380,32 +1282,42 @@ bool PoseCommand::Execute()
     return false;
   }
 
-  return updatePose(*poseMsg, this->iface);
-}
-
-//////////////////////////////////////////////////
-PoseVectorCommand::PoseVectorCommand(msgs::Pose_V *_msg,
-    std::shared_ptr<UserCommandsInterface> &_iface)
-    : UserCommandBase(_msg, _iface)
-{
-}
-
-//////////////////////////////////////////////////
-bool PoseVectorCommand::Execute()
-{
-  auto poseVectorMsg = dynamic_cast<const msgs::Pose_V *>(this->msg);
-  if (nullptr == poseVectorMsg)
+  // Check the name of the entity being spawned
+  std::string entityName = poseMsg->name();
+  Entity entity = kNullEntity;
+  // TODO(anyone) Update pose message to use Entity, with default ID null
+  if (poseMsg->id() != kNullEntity && poseMsg->id() != 0)
   {
-    ignerr << "Internal error, null create message" << std::endl;
+    entity = poseMsg->id();
+  }
+  else if (!entityName.empty())
+  {
+    entity = this->iface->ecm->EntityByComponents(components::Name(entityName),
+      components::ParentEntity(this->iface->worldEntity));
+  }
+
+  if (!this->iface->ecm->HasEntity(entity))
+  {
+    ignerr << "Unable to update the pose for entity id:[" << poseMsg->id()
+           << "], name[" << entityName << "]" << std::endl;
     return false;
   }
 
-  for (int i = 0; i < poseVectorMsg->pose_size(); i++)
+  auto poseCmdComp =
+    this->iface->ecm->Component<components::WorldPoseCmd>(entity);
+  if (!poseCmdComp)
   {
-    if (!updatePose(poseVectorMsg->pose(i), this->iface))
-    {
-      return false;
-    }
+    this->iface->ecm->CreateComponent(
+        entity, components::WorldPoseCmd(msgs::Convert(*poseMsg)));
+  }
+  else
+  {
+    /// \todo(anyone) Moving an object is not captured in a log file.
+    auto state = poseCmdComp->SetData(msgs::Convert(*poseMsg), pose3Eql) ?
+        ComponentState::OneTimeChange :
+        ComponentState::NoChange;
+    this->iface->ecm->SetChanged(entity, components::WorldPoseCmd::typeId,
+        state);
   }
 
   return true;
@@ -1445,6 +1357,86 @@ bool PhysicsCommand::Execute()
   return true;
 }
 
+//////////////////////////////////////////////////
+SphericalCoordinatesCommand::SphericalCoordinatesCommand(
+    msgs::SphericalCoordinates *_msg,
+    std::shared_ptr<UserCommandsInterface> &_iface)
+    : UserCommandBase(_msg, _iface)
+{
+}
+
+//////////////////////////////////////////////////
+bool SphericalCoordinatesCommand::Execute()
+{
+  auto sphericalCoordinatesMsg =
+      dynamic_cast<const msgs::SphericalCoordinates *>(this->msg);
+  if (nullptr == sphericalCoordinatesMsg)
+  {
+    ignerr << "Internal error, null SphericalCoordinates message" << std::endl;
+    return false;
+  }
+
+  // World
+  if (!sphericalCoordinatesMsg->has_entity())
+  {
+    World world(this->iface->worldEntity);
+    world.SetSphericalCoordinates(*this->iface->ecm,
+        msgs::Convert(*sphericalCoordinatesMsg));
+    return true;
+  }
+
+  // Entity
+  auto entity = topLevelEntityFromMessage(*this->iface->ecm,
+      sphericalCoordinatesMsg->entity());
+
+  if (!this->iface->ecm->HasEntity(entity))
+  {
+    ignerr << "Unable to update the pose for entity [" << entity
+           << "]: entity doesn't exist." << std::endl;
+    return false;
+  }
+
+  auto scComp = this->iface->ecm->Component<components::SphericalCoordinates>(
+      this->iface->worldEntity);
+  if (nullptr == scComp)
+  {
+    ignerr << "Trying to move entity [" << entity
+           << "] using spherical coordinates, but world's spherical "
+           << "coordinates aren't set." << std::endl;
+    return false;
+  }
+
+  // deg to rad
+  math::Vector3d latLonEle{
+      IGN_DTOR(sphericalCoordinatesMsg->latitude_deg()),
+      IGN_DTOR(sphericalCoordinatesMsg->longitude_deg()),
+      sphericalCoordinatesMsg->elevation()};
+
+  auto pos = scComp->Data().PositionTransform(latLonEle,
+      math::SphericalCoordinates::SPHERICAL,
+      math::SphericalCoordinates::LOCAL2);
+
+  math::Pose3d pose{pos.X(), pos.Y(), pos.Z(), 0, 0,
+          IGN_DTOR(sphericalCoordinatesMsg->heading_deg())};
+
+  auto poseCmdComp =
+    this->iface->ecm->Component<components::WorldPoseCmd>(entity);
+  if (!poseCmdComp)
+  {
+    this->iface->ecm->CreateComponent(entity, components::WorldPoseCmd(pose));
+  }
+  else
+  {
+    auto state = poseCmdComp->SetData(pose, pose3Eql) ?
+        ComponentState::OneTimeChange :
+        ComponentState::NoChange;
+    this->iface->ecm->SetChanged(entity, components::WorldPoseCmd::typeId,
+        state);
+  }
+
+  return true;
+}
+
 //////////////////////////////////////////////////
 EnableCollisionCommand::EnableCollisionCommand(msgs::Entity *_msg,
     std::shared_ptr<UserCommandsInterface> &_iface)
@@ -1588,130 +1580,6 @@ bool VisualCommand::Execute()
   return true;
 }
 
-//////////////////////////////////////////////////
-WheelSlipCommand::WheelSlipCommand(msgs::WheelSlipParametersCmd *_msg,
-    std::shared_ptr<UserCommandsInterface> &_iface)
-    : UserCommandBase(_msg, _iface)
-{
-}
-
-// TODO(ivanpauno): Move this somewhere else
-Entity scopedEntityFromMsg(
-  const msgs::Entity & _msg, const EntityComponentManager & _ecm)
-{
-  if (_msg.id() != kNullEntity) {
-    return _msg.id();
-  }
-  std::unordered_set<Entity> entities = entitiesFromScopedName(
-    _msg.name(), _ecm);
-  if (entities.empty()) {
-    ignerr << "Failed to find entity with scoped name [" << _msg.name()
-          << "]." << std::endl;
-    return kNullEntity;
-  }
-  if (_msg.type() == msgs::Entity::NONE) {
-    return *entities.begin();
-  }
-  const components::BaseComponent * component;
-  std::string componentType;
-  for (const auto entity : entities) {
-    switch (_msg.type()) {
-      case msgs::Entity::LIGHT:
-        component = _ecm.Component<components::Light>(entity);
-        componentType = "LIGHT";
-        break;
-      case msgs::Entity::MODEL:
-        component = _ecm.Component<components::Model>(entity);
-        componentType = "MODEL";
-        break;
-      case msgs::Entity::LINK:
-        component = _ecm.Component<components::Link>(entity);
-        componentType = "LINK";
-        break;
-      case msgs::Entity::VISUAL:
-        component = _ecm.Component<components::Visual>(entity);
-        componentType = "VISUAL";
-        break;
-      case msgs::Entity::COLLISION:
-        component = _ecm.Component<components::Collision>(entity);
-        componentType = "COLLISION";
-        break;
-      case msgs::Entity::SENSOR:
-        component = _ecm.Component<components::Sensor>(entity);
-        componentType = "SENSOR";
-        break;
-      case msgs::Entity::JOINT:
-        component = _ecm.Component<components::Joint>(entity);
-        componentType = "JOINT";
-        break;
-      default:
-        componentType = "unknown";
-        break;
-    }
-    if (component != nullptr) {
-      return entity;
-    }
-  }
-  ignerr << "Found entity with scoped name [" << _msg.name()
-        << "], but it doesn't have a component of the required type ["
-        << componentType << "]." << std::endl;
-  return kNullEntity;
-}
-
-//////////////////////////////////////////////////
-bool WheelSlipCommand::Execute()
-{
-  auto wheelSlipMsg = dynamic_cast<const msgs::WheelSlipParametersCmd *>(
-      this->msg);
-  if (nullptr == wheelSlipMsg)
-  {
-    ignerr << "Internal error, null wheel slip message" << std::endl;
-    return false;
-  }
-  const auto & ecm = *this->iface->ecm;
-  Entity entity = scopedEntityFromMsg(wheelSlipMsg->entity(), ecm);
-  if (kNullEntity == entity)
-  {
-    return false;
-  }
-
-  auto doForEachLink = [this, wheelSlipMsg](Entity linkEntity) {
-    auto wheelSlipCmdComp =
-      this->iface->ecm->Component<components::WheelSlipCmd>(linkEntity);
-    if (!wheelSlipCmdComp)
-    {
-      this->iface->ecm->CreateComponent(
-          linkEntity, components::WheelSlipCmd(*wheelSlipMsg));
-    }
-    else
-    {
-      auto state = wheelSlipCmdComp->SetData(
-        *wheelSlipMsg, this->wheelSlipEql) ? ComponentState::OneTimeChange
-        : ComponentState::NoChange;
-      this->iface->ecm->SetChanged(
-          linkEntity, components::WheelSlipCmd::typeId, state);
-    }
-  };
-  const components::BaseComponent * component =
-    ecm.Component<components::Link>(entity);
-
-  if (nullptr != component) {
-    doForEachLink(entity);
-    return true;
-  }
-  component = ecm.Component<components::Model>(entity);
-  if (nullptr != component) {
-    Model model{entity};
-    for (const auto & linkEntity : model.Links(*this->iface->ecm)) {
-      doForEachLink(linkEntity);
-    }
-    return true;
-  }
-  ignerr << "Found entity with scoped name [" << wheelSlipMsg->entity().name()
-          << "], is neither a model or a link." << std::endl;
-  return false;
-}
-
 IGNITION_ADD_PLUGIN(UserCommands, System,
   UserCommands::ISystemConfigure,
   UserCommands::ISystemPreUpdate
