@@ -22,7 +22,6 @@
 #include <ignition/common/Console.hh>
 #include <ignition/common/Util.hh>
 #include <ignition/transport/Node.hh>
-#include <ignition/utilities/ExtraTestMacros.hh>
 
 #include "ignition/gazebo/components/Joint.hh"
 #include "ignition/gazebo/components/Name.hh"
@@ -47,9 +46,7 @@ class ApplyJointForceTestFixture : public InternalFixture<::testing::Test>
 
 /////////////////////////////////////////////////
 // Tests that the ApplyJointForce accepts joint velocity commands
-// See https://github.com/ignitionrobotics/ign-gazebo/issues/1175
-TEST_F(ApplyJointForceTestFixture,
-       IGN_UTILS_TEST_DISABLED_ON_WIN32(JointVelocityCommand))
+TEST_F(ApplyJointForceTestFixture, JointVelocityCommand)
 {
   using namespace std::chrono_literals;
 
