@@ -19,12 +19,9 @@
 
 #include <ignition/common/Console.hh>
 #include <ignition/common/Util.hh>
-#include <ignition/utilities/ExtraTestMacros.hh>
 
-#include "ignition/gazebo/Util.hh"
 #include "ignition/gazebo/Server.hh"
 #include "ignition/gazebo/SystemLoader.hh"
-#include "ignition/gazebo/TestFixture.hh"
 #include "ignition/gazebo/components/CenterOfVolume.hh"
 #include "ignition/gazebo/components/Link.hh"
 #include "ignition/gazebo/components/Name.hh"
@@ -45,8 +42,7 @@ class BuoyancyTest : public InternalFixture<::testing::Test>
 };
 
 /////////////////////////////////////////////////
-// See https://github.com/ignitionrobotics/ign-gazebo/issues/1175
-TEST_F(BuoyancyTest, IGN_UTILS_TEST_DISABLED_ON_WIN32(Movement))
+TEST_F(BuoyancyTest, UniformWorldMovement)
 {
   // Start server
   ServerConfig serverConfig;
@@ -187,7 +183,7 @@ TEST_F(BuoyancyTest, IGN_UTILS_TEST_DISABLED_ON_WIN32(Movement))
 
     if (_info.iterations == iterations)
     {
-      EXPECT_NEAR(-1.63, submarineSinkingPose->Data().Pos().Z(), 1e-2);
+      EXPECT_NEAR(-1.64, submarineSinkingPose->Data().Pos().Z(), 1e-2);
       EXPECT_NEAR(4.90, submarineBuoyantPose->Data().Pos().Z(), 1e-2);
       EXPECT_NEAR(171.4, duckPose->Data().Pos().Z(), 1e-2);
       finished = true;
@@ -200,75 +196,85 @@ TEST_F(BuoyancyTest, IGN_UTILS_TEST_DISABLED_ON_WIN32(Movement))
 }
 
 /////////////////////////////////////////////////
-TEST_F(BuoyancyTest, IGN_UTILS_TEST_DISABLED_ON_WIN32(OffsetAndRotation))
+TEST_F(BuoyancyTest, GradedBuoyancy)
 {
-  TestFixture fixture(common::joinPaths(std::string(PROJECT_SOURCE_PATH),
-    "test", "worlds", "center_of_volume.sdf"));
+  // Start server
+  ServerConfig serverConfig;
+  const auto sdfFile = common::joinPaths(std::string(PROJECT_SOURCE_PATH),
+    "test", "worlds", "graded_buoyancy.sdf");
+  serverConfig.SetSdfFile(sdfFile);
 
-  std::size_t iterations{0};
-  fixture.OnPostUpdate([&](
-      const gazebo::UpdateInfo &,
-      const gazebo::EntityComponentManager &_ecm)
+  Server server(serverConfig);
+  EXPECT_FALSE(server.Running());
+  EXPECT_FALSE(*server.Running(0));
+
+  using namespace std::chrono_literals;
+  server.SetUpdatePeriod(1ns);
+
+  std::size_t iterations = 1000;
+
+  bool finished = false;
+  test::Relay testSystem;
+  testSystem.OnPostUpdate([&](const gazebo::UpdateInfo &_info,
+                             const gazebo::EntityComponentManager &_ecm)
   {
-    // Get links
-    auto noOffsets = entitiesFromScopedName("no_offset::link", _ecm);
-    ASSERT_EQ(1u, noOffsets.size());
-    auto noOffset = *noOffsets.begin();
-    EXPECT_NE(kNullEntity, noOffset);
+    // Check pose
+    Entity neutralBox = _ecm.EntityByComponents(
+        components::Model(), components::Name("neutral_buoyancy"));
 
-    auto noOffsetRotateds = entitiesFromScopedName("no_offset_rotated::link",
-        _ecm);
-    ASSERT_EQ(1u, noOffsetRotateds.size());
-    auto noOffsetRotated = *noOffsetRotateds.begin();
-    EXPECT_NE(kNullEntity, noOffsetRotated);
+    Entity bobbingBall = _ecm.EntityByComponents(
+        components::Model(), components::Name("lighter_than_water"));
 
-    auto withOffsets = entitiesFromScopedName("com_cov_offset::link", _ecm);
-    ASSERT_EQ(1u, withOffsets.size());
-    auto withOffset = *withOffsets.begin();
-    EXPECT_NE(kNullEntity, withOffset);
+    Entity heliumBalloon = _ecm.EntityByComponents(
+        components::Model(), components::Name("balloon_lighter_than_air"));
 
-    auto withOffsetRotateds = entitiesFromScopedName(
-        "com_cov_offset_rotated::link", _ecm);
-    ASSERT_EQ(1u, withOffsetRotateds.size());
-    auto withOffsetRotated = *withOffsetRotateds.begin();
-    EXPECT_NE(kNullEntity, withOffsetRotated);
+    Entity noBuoyancy = _ecm.EntityByComponents(
+        components::Model(), components::Name("box_no_buoyancy"));
 
-    // Check CoVs have correct offsets
-    auto noOffsetCoV = _ecm.Component<components::CenterOfVolume>(noOffset);
-    ASSERT_NE(noOffsetCoV, nullptr);
-    EXPECT_EQ(math::Vector3d::Zero, noOffsetCoV->Data());
+    ASSERT_NE(neutralBox, kNullEntity);
+    ASSERT_NE(bobbingBall, kNullEntity);
+    ASSERT_NE(heliumBalloon, kNullEntity);
+    ASSERT_NE(noBuoyancy, kNullEntity);
 
-    auto noOffsetRotatedCoV = _ecm.Component<components::CenterOfVolume>(
-        noOffsetRotated);
-    ASSERT_NE(noOffsetRotatedCoV, nullptr);
-    EXPECT_EQ(math::Vector3d::Zero, noOffsetRotatedCoV->Data());
+    auto neutralBoxPose = _ecm.Component<components::Pose>(neutralBox);
+    ASSERT_NE(neutralBoxPose, nullptr);
 
-    auto withOffsetCoV = _ecm.Component<components::CenterOfVolume>(withOffset);
-    ASSERT_NE(withOffsetCoV, nullptr);
-    EXPECT_EQ(math::Vector3d::One, withOffsetCoV->Data());
+    auto bobbingBallPose = _ecm.Component<components::Pose>(bobbingBall);
+    ASSERT_NE(bobbingBallPose , nullptr);
 
-    auto withOffsetRotatedCoV = _ecm.Component<components::CenterOfVolume>(
-        withOffsetRotated);
-    ASSERT_NE(withOffsetRotatedCoV, nullptr);
-    EXPECT_EQ(math::Vector3d::One, withOffsetRotatedCoV->Data());
+    auto heliumBalloonPose = _ecm.Component<components::Pose>(heliumBalloon);
+    ASSERT_NE(heliumBalloonPose , nullptr);
 
-    // Check that all objects are neutrally buoyant and stay still
-    auto noOffsetPose = worldPose(noOffset, _ecm);
-    EXPECT_EQ(math::Pose3d(), noOffsetPose);
+    auto noBuoyancyPose = _ecm.Component<components::Pose>(noBuoyancy);
+    ASSERT_NE(noBuoyancyPose , nullptr);
 
-    auto noOffsetRotatedPose = worldPose(noOffsetRotated, _ecm);
-    EXPECT_EQ(math::Pose3d(-3, 0, 0, 0.1, 0.2, 0.3), noOffsetRotatedPose);
+    // The "neutralBox" should stay in its starting location.
+    EXPECT_NEAR(0, neutralBoxPose->Data().Pos().X(), 1e-1);
+    EXPECT_NEAR(5, neutralBoxPose->Data().Pos().Y(), 1e-1);
+    EXPECT_NEAR(-3, neutralBoxPose->Data().Pos().Z(), 1e-1);
 
-    auto withOffsetPose = worldPose(withOffset, _ecm);
-    EXPECT_EQ(math::Pose3d(0, 3, 0, 0, 0, 0), withOffsetPose);
+    if (_info.iterations > 10)
+    {
+      // Helium balloon should float up
+      EXPECT_GT(heliumBalloonPose->Data().Pos().Z(),
+                neutralBoxPose->Data().Pos().Z());
 
-    auto withOffsetRotatedPose = worldPose(withOffsetRotated, _ecm);
-    EXPECT_EQ(math::Pose3d(-3, 3, 0, 0.1, 0.2, 0.3), withOffsetRotatedPose);
+      // Bobbing ball should stay within a certain band.
+      EXPECT_GT(bobbingBallPose->Data().Pos().Z(), -1.2);
+      EXPECT_LT(bobbingBallPose->Data().Pos().Z(), 0.5);
 
-    iterations++;
-  }).Finalize();
+      // No buoyancy box should sink
+      EXPECT_LT(noBuoyancyPose->Data().Pos().Z(),
+                neutralBoxPose->Data().Pos().Z());
+    }
 
-  std::size_t targetIterations{1000};
-  fixture.Server()->Run(true, targetIterations, false);
-  EXPECT_EQ(targetIterations, iterations);
+    if (_info.iterations == iterations)
+    {
+      finished = true;
+    }
+  });
+
+  server.AddSystem(testSystem.systemPtr);
+  server.Run(true, iterations, false);
+  EXPECT_TRUE(finished);
 }
