@@ -84,9 +84,7 @@ class Relay
 
 
 /////////////////////////////////////////////////
-// See https://github.com/ignitionrobotics/ign-gazebo/issues/1175
-TEST_P(FollowActorTest,
-       IGN_UTILS_TEST_ENABLED_ONLY_ON_LINUX(PublishCmd))
+TEST_P(FollowActorTest, IGN_UTILS_TEST_DISABLED_ON_MAC(PublishCmd))
 {
   // Start server
   ServerConfig serverConfig;
