@@ -44,6 +44,7 @@
 
 #include "plugins/MockSystem.hh"
 #include "../helpers/Relay.hh"
+#include "../helpers/EnvTestFixture.hh"
 
 using namespace ignition;
 using namespace gazebo;
@@ -57,7 +58,7 @@ class ModelMover: public test::Relay
   public: explicit ModelMover(Entity _entity): test::Relay(), entity(_entity)
   {
     using namespace std::placeholders;
-    this->mockSystem->preUpdateCallback =
+    this->systemPtr->preUpdateCallback =
         std::bind(&ModelMover::MoveModel, this, _1, _2);
   }
 
@@ -94,15 +95,12 @@ class ModelMover: public test::Relay
 };
 
 //////////////////////////////////////////////////
-class LevelManagerFixture : public ::testing::Test
+class LevelManagerFixture : public InternalFixture<::testing::Test>
 {
   // Documentation inherited
   protected: void SetUp() override
   {
-    common::Console::SetVerbosity(4);
-
-    ignition::common::setenv("IGN_GAZEBO_SYSTEM_PLUGIN_PATH",
-      (std::string(PROJECT_BINARY_PATH) + "/lib").c_str());
+    InternalFixture::SetUp();
 
     ignition::gazebo::ServerConfig serverConfig;
 
