@@ -18,7 +18,6 @@
 
 #include <ignition/common/Console.hh>
 #include <ignition/common/Util.hh>
-#include <ignition/utilities/ExtraTestMacros.hh>
 
 #include "ignition/math/Pose3.hh"
 #include "ignition/gazebo/Server.hh"
@@ -42,8 +41,7 @@ class NestedModelPhysicsTest : public InternalFixture<::testing::Test>
 /////////////////////////////////////////////////
 /// Test that a tower of 3 boxes built with an <include> and further nesting
 /// moves appropriately with joints in dartsim
-// See https://github.com/ignitionrobotics/ign-gazebo/issues/1175
-TEST_F(NestedModelPhysicsTest, IGN_UTILS_TEST_DISABLED_ON_WIN32(Movement))
+TEST_F(NestedModelPhysicsTest, Movement)
 {
   // Start server
   ServerConfig serverConfig;
