@@ -33,6 +33,7 @@
 #include "ignition/gazebo/test_config.hh"
 
 #include "../helpers/Relay.hh"
+#include "../helpers/EnvTestFixture.hh"
 
 #define tol 10e-4
 
@@ -40,15 +41,8 @@ using namespace ignition;
 using namespace gazebo;
 
 /// \brief Test PosePublisher system
-class PosePublisherTest : public ::testing::TestWithParam<int>
+class PosePublisherTest : public InternalFixture<::testing::TestWithParam<int>>
 {
-  // Documentation inherited
-  protected: void SetUp() override
-  {
-    common::Console::SetVerbosity(4);
-    ignition::common::setenv("IGN_GAZEBO_SYSTEM_PLUGIN_PATH",
-           (std::string(PROJECT_BINARY_PATH) + "/lib").c_str());
-  }
 };
 
 std::mutex mutex;
@@ -356,9 +350,9 @@ TEST_F(PosePublisherTest, UpdateFrequency)
   std::size_t nExpMessages = 100;
   // Wait for 100 messages to be received
   bool received = false;
-  for (int sleep = 0; sleep < 300; ++sleep)
+  for (int sleep = 0; sleep < 30; ++sleep)
   {
-    std::this_thread::sleep_for(std::chrono::milliseconds(10));
+    std::this_thread::sleep_for(std::chrono::milliseconds(100));
 
     {
       std::lock_guard<std::mutex> lock(mutex);
@@ -678,9 +672,9 @@ TEST_F(PosePublisherTest, StaticPoseUpdateFrequency)
   std::size_t nExpMessages = 100;
   // Wait for 100 messages to be received
   bool received = false;
-  for (int sleep = 0; sleep < 300; ++sleep)
+  for (int sleep = 0; sleep < 30; ++sleep)
   {
-    std::this_thread::sleep_for(std::chrono::milliseconds(10));
+    std::this_thread::sleep_for(std::chrono::milliseconds(100));
 
     {
       std::lock_guard<std::mutex> lock(mutex);
@@ -738,9 +732,9 @@ TEST_F(PosePublisherTest, NestedModelLoadPlugin)
 
   // Wait for messages to be received
   int sleep = 0;
-  while (poseMsgs.empty() && sleep++ < 300)
+  while (poseMsgs.empty() && sleep++ < 30)
   {
-    std::this_thread::sleep_for(std::chrono::milliseconds(10));
+    std::this_thread::sleep_for(std::chrono::milliseconds(100));
   }
 
   EXPECT_TRUE(!poseMsgs.empty());
