@@ -49,20 +49,14 @@
 
 #include "plugins/MockSystem.hh"
 #include "../helpers/Relay.hh"
+#include "../helpers/EnvTestFixture.hh"
 
 using namespace ignition;
 using namespace gazebo;
 
 /// \brief Test DiffDrive system
-class WheelSlipTest : public ::testing::Test
+class WheelSlipTest : public InternalFixture<::testing::Test>
 {
-  // Documentation inherited
-  protected: void SetUp() override
-             {
-               common::Console::SetVerbosity(4);
-               ignition::common::setenv("IGN_GAZEBO_SYSTEM_PLUGIN_PATH",
-                   (std::string(PROJECT_BINARY_PATH) + "/lib").c_str());
-             }
   /// \brief Class to hold parameters for tire tests.
   public: class WheelSlipState
   {
@@ -554,12 +548,15 @@ TEST_F(WheelSlipTest, TricyclesUphill)
   server.AddSystem(testSlipSystem.systemPtr);
   server.Run(true, 2000, false);
 
+  // Slip works on DART>=6.10, which isn't available on Ubuntu Focal
+#ifndef __linux__
   // compute expected slip
   // normal force as passed to Wheel Slip in test world
   const double wheelNormalForce = 32;
   const double mass = 14.5;
   const double forceRatio =
     (mass/2) * std::abs(gravity->Data().X()) / wheelNormalForce;
+#endif
   const double noSlipLinearSpeed = wheelRadius * angularSpeed;
 
   auto wheelRearLeftVelocity =
@@ -590,6 +587,9 @@ TEST_F(WheelSlipTest, TricyclesUphill)
 
   EXPECT_NEAR(angularSpeed, wheelRearLeftVelocity->Data()[0], 3e-3);
   EXPECT_NEAR(angularSpeed, wheelRearRightVelocity->Data()[0], 3e-3);
+  // Slip works on DART>=6.10, which isn't available on Ubuntu Focal
+#ifndef __linux__
   EXPECT_NEAR(noSlipLinearSpeed - worldVelTrisphere1->Data()[0],
       noSlipLinearSpeed * forceRatio, 5e-3);
+#endif
 }
